From 0572ee94bbd7acbf6c0bb6134e7212e84be306a1 Mon Sep 17 00:00:00 2001
From: Jakob Leben <jleben@videolan.org>
Date: Wed, 16 Sep 2009 11:33:47 +0200
Subject: [PATCH] vout_wrapper: set object name per submodule + Qt4: fix vout selection in preferences

Setting object name of each vout_wrapper submodule to it's specific shortcut
automatically solves the issue in Qt preferences, where selecting each of the
submodules results in the same final choice.
---
 include/vlc_plugin.h           |    5 +++++
 modules/video_output/wrapper.c |    1 +
 2 files changed, 6 insertions(+), 0 deletions(-)

diff --git a/include/vlc_plugin.h b/include/vlc_plugin.h
index 5306825..a1e1f8d 100644
--- a/include/vlc_plugin.h
+++ b/include/vlc_plugin.h
@@ -205,6 +205,11 @@ enum vlc_module_properties
         (const char *)(shortcut))) \
         goto error;
 
+#define set_name( name ) \
+    if (vlc_module_set (p_submodule, VLC_MODULE_NAME, \
+                    (const char *)(name))) \
+    goto error;
+
 #define set_shortname( shortname ) \
     if (vlc_module_set (p_submodule, VLC_MODULE_SHORTNAME, domain, \
                         (const char *)(shortname))) \
diff --git a/modules/video_output/wrapper.c b/modules/video_output/wrapper.c
index d7e5e16..d4fe029 100644
--- a/modules/video_output/wrapper.c
+++ b/modules/video_output/wrapper.c
@@ -60,6 +60,7 @@ DECLARE_OPEN(vmem);
 #undef DECLARE_OPEN
 
 #define DECLARE_MODULE(name, priority)                  \
+    set_name( #name )                                   \
     set_description( "Video display "#name" wrapper" )  \
     set_shortname( "Video display "#name" wrapper" )    \
     set_capability( "video output", priority )          \
-- 
1.6.0.4

